@@ -72,17 +72,9 @@ class Client:
         self.username = username
         self.client_name = client_name
         self.scheme = scheme
+        self.password = password
 
-        self.connection = self.create_connection(
-            host,
-            port,
-            db,
-            password,
-            path,
-            scheme,
-            username,
-            client_name=client_name,
-        )
+        self.build_connection()
 
         # all command upper case
         self.answer_callbacks = command2callback
@@ -104,6 +96,21 @@ class Client:
         if config.version and re.match(r"([\d\.]+)", config.version):
             self.auth_compat(config.version)
 
+    def build_connection(self):
+        """
+        create a new connection and replace ``self.connection``
+        """
+        self.connection = self.create_connection(
+            self.host,
+            self.port,
+            self.db,
+            self.password,
+            self.path,
+            self.scheme,
+            self.username,
+            client_name=self.client_name,
+        )
+
     def create_connection(
         self,
         host=None,
@@ -217,7 +224,7 @@ class Client:
         logger.info(
             f"execute by connection: connection={connection}, name={command_name}, {args}, {options}"
         )
-        retry_times = config.retry_times  # FIXME configureable
+        retry_times = config.retry_times  # FIXME configurable
         last_error = None
         need_refresh_connection = False
 
@@ -252,6 +259,15 @@ class Client:
             except redis.exceptions.ExecAbortError:
                 config.transaction = False
                 raise
+            except KeyboardInterrupt:
+                logger.warning("received KeyboardInterrupt... rebuild connection...")
+                connection.disconnect()
+                connection.connect()
+                print(
+                    "KeyboardInterrupt received! User canceled reading response!",
+                    file=sys.stderr,
+                )
+                return None
             else:
                 return response
         raise last_error
@@ -471,7 +487,7 @@ class Client:
         """
         if command_name.upper() == "HELLO":
             raise NotSupport("IRedis currently not support RESP3, sorry about that.")
-        # TRANSATION state chage
+        # TRANSACTION state change
         if command_name.upper() in ["EXEC", "DISCARD"]:
             logger.debug(f"[After hook] Command is {command_name}, unset transaction.")
             config.transaction = False
@@ -511,25 +527,25 @@ class Client:
         rendered_detail = markdown.render(doc)
         summary_dict = commands_summary[command_summary_name]
 
-        avaiable_version = summary_dict.get("since", "?")
+        available_version = summary_dict.get("since", "?")
         server_version = config.version
         # FIXME anything strange with single quotes?
         logger.debug(f"[--version--] '{server_version}'")
         try:
-            is_avaiable = StrictVersion(server_version) > StrictVersion(
-                avaiable_version
+            is_available = StrictVersion(server_version) > StrictVersion(
+                available_version
             )
         except Exception as e:
             logger.exception(e)
-            is_avaiable = None
+            is_available = None
 
-        if is_avaiable:
-            avaiable_text = f"(Avaiable on your redis-server: {server_version})"
-        elif is_avaiable is False:
-            avaiable_text = f"(Not avaiable on your redis-server: {server_version})"
+        if is_available:
+            available_text = f"(Available on your redis-server: {server_version})"
+        elif is_available is False:
+            available_text = f"(Not available on your redis-server: {server_version})"
         else:
-            avaiable_text = ""
-        since_text = f"{avaiable_version} {avaiable_text}"
+            available_text = ""
+        since_text = f"{available_version} {available_text}"
 
         summary = [
             ("", "\n"),
@@ -642,7 +658,7 @@ class Client:
             yield FormattedText([("class:dockey", "XINFO: ")])
             yield renders.OutputRender.render_list(xinfo)
 
-        # incase the result is too long, we yield only once so the outputer
+        # in case the result is too long, we yield only once so the outputer
         # can pager it.
         peek_response = []
         key_type = nativestr(self.execute("type", key))
