@@ -6,7 +6,7 @@ import functools
 from importlib_resources import read_text, open_text
 
 from .utils import timer, strip_quote_args
-from .exceptions import InvalidArguments
+from .exceptions import InvalidArguments, AmbiguousCommand
 from . import data as project_data
 
 
@@ -20,7 +20,7 @@ def _load_command_summary():
 
 def _load_command():
     """
-    load command informations from file.
+    load command information from file.
     :returns:
         - original_commans: dict, command name : Command
         - command_group: dict, group_name: command_names
@@ -94,7 +94,6 @@ commands_summary.update(
         "PEEK": {
             "summary": "Get the key's type and value.",
             "arguments": [{"name": "key", "type": "key"}],
-            "since": "1.0",
             "complexity": "O(1).",
             "since": "1.0",
             "group": "iredis",
@@ -116,7 +115,17 @@ def split_command_args(command):
 
     command = command.strip()
     for command_name in all_commands:
-        # allow multiplt space in user inputed command
+        # for command that is paritaly input, like `command in`, we should
+        # match with `command info`, otherwise, `command in` will result in
+        # `command` with `args` is ('in') which is an invalid case.
+        normalized_input_command = " ".join(command.split()).upper()
+        if (
+            re.search("\s", command)
+            and command_name.startswith(normalized_input_command)
+            and command_name != normalized_input_command
+        ):
+            raise AmbiguousCommand("command is not finished")
+        # allow multiple space in user input command
         command_allow_multi_spaces = "[ ]+".join(command_name.split())
         matcher = re.match(fr"({command_allow_multi_spaces})( |$)", command.upper())
         if matcher:
@@ -125,7 +134,7 @@ def split_command_args(command):
             input_args = command[matcher.end() :]
             break
     else:
-        raise InvalidArguments(f"`{command}` is not a valide Redis Command")
+        raise InvalidArguments(f"`{command}` is not a valid Redis Command")
 
     args = list(strip_quote_args(input_args))
 
