@@ -123,6 +123,13 @@ CONST = {
     "reset_const": "RESET",
     "const_user": "USER",
     "full_const": "FULL",
+    "str_algo": "LCS",
+    "len_const": "LEN",
+    "idx_const": "IDX",
+    "minmatchlen_const": "MINMATCHLEN",
+    "withmatchlen_const": "WITHMATCHLEN",
+    "strings_const": "STRINGS",
+    "rank_const": "RANK",
 }
 
 
@@ -140,7 +147,7 @@ VALID_TOKEN = r"""(
 )"""
 PATTERN = fr"(?P<pattern>{VALID_TOKEN})"
 VALID_SLOT = r"\d+"  # TODO add range? max value:16384
-VALID_NODE = r"\d+"
+VALID_NODE = r"\w+"
 NUM = r"\d+"
 NNUM = r"-?\+?\(?\[?(\d+|inf)"  # number cloud be negative
 _FLOAT = r"-?(\d|\.|e)+"
@@ -156,6 +163,7 @@ DESTINATION = fr"(?P<destination>{VALID_TOKEN})"
 NEWKEY = fr"(?P<newkey>{VALID_TOKEN})"
 VALUE = fr"(?P<value>{VALID_TOKEN})"
 VALUES = fr"(?P<values>{VALID_TOKEN}(\s+{VALID_TOKEN})*)"
+ELEMENT = fr"(?P<element>{VALID_TOKEN})"  # element for list
 FIELDS = fr"(?P<fields>{VALID_TOKEN}(\s+{VALID_TOKEN})*)"
 FIELD = fr"(?P<field>{VALID_TOKEN})"
 SFIELD = fr"(?P<sfield>{VALID_TOKEN})"
@@ -163,6 +171,8 @@ SVALUE = fr"(?P<svalue>{VALID_TOKEN})"
 MEMBER = fr"(?P<member>{VALID_TOKEN})"
 MEMBERS = fr"(?P<members>{VALID_TOKEN}(\s+{VALID_TOKEN})*)"
 COUNT = fr"(?P<count>{NNUM})"
+LEN = fr"(?P<len>{NNUM})"
+RANK = fr"(?P<rank>{NNUM})"
 VERSION_NUM = fr"(?P<version_num>{NUM})"
 MESSAGE = fr"(?P<message>{VALID_TOKEN})"
 CHANNEL = fr"(?P<channel>{VALID_TOKEN})"
@@ -311,6 +321,14 @@ NOLOOP_CONST = fr"(?P<noloop_const>{c('noloop_const')})"
 RESET_CONST = fr"(?P<reset_const>{c('reset_const')})"
 FULL_CONST = fr"(?P<full_const>{c('full_const')})"
 
+STR_ALGO = fr"(?P<str_algo>{c('str_algo')})"
+LEN_CONST = fr"(?P<len_const>{c('len_const')})"
+IDX_CONST = fr"(?P<idx_const>{c('idx_const')})"
+MINMATCHLEN_CONST = fr"(?P<minmatchlen_const>{c('minmatchlen_const')})"
+WITHMATCHLEN_CONST = fr"(?P<withmatchlen_const>{c('withmatchlen_const')})"
+STRINGS_CONST = fr"(?P<strings_const>{c('strings_const')})"
+RANK_CONST = fr"(?P<rank_const>{c('rank_const')})"
+
 command_grammar = compile(COMMAND)
 
 # Here are the core grammars, those are tokens after ``command``.
@@ -446,9 +464,16 @@ GRAMMAR = {
             (\s+ {CONST_USER} \s+ {USERNAME})|
             (\s+ {SKIPME} \s+ {YES})
         )+ \s*""",
-    "command_migrate": fr"""\s+ {HOST} \s+ {PORT}
-        \s+ {KEY} \s+ {INDEX} \s+ {TIMEOUT} (\s+ {MIGRATECHOICE})?
-        (\s+ {AUTH} \s+ {PASSWORD})? (\s+ {CONST_KEYS} \s+ {KEYS})? \s*""",
+    "command_migrate": fr"""
+        \s+ {HOST} \s+ {PORT}
+        \s+ {KEY} \s+ {INDEX} \s+ {TIMEOUT}
+        (\s+ {MIGRATECHOICE})?
+        (
+            (\s+ {AUTH} \s+ {PASSWORD})|
+            (\s+ {AUTH} \s+ {USERNAME} \s+ {PASSWORD})
+        )?
+        (\s+ {CONST_KEYS} \s+ {KEYS})?
+    \s*""",
     "command_radius": fr"""\s+ {KEY}
         \s+ {LONGITUDE} \s+ {LATITUDE} \s+ {FLOAT} \s+ {DISTUNIT}
         (\s+ {GEOCHOICE})* (\s+ {COUNT_CONST} \s+ {COUNT})?
@@ -561,6 +586,27 @@ GRAMMAR = {
     "command_count_or_resetx": fr"( (\s+ {COUNT}) | (\s+ {RESET_CONST}) )? \s*",
     "command_username_rules": fr"\s+ {USERNAME} (\s+ {RULE})* \s*",
     "command_count": fr"(\s+ {COUNT})? \s*",
+    "command_stralgo": fr"""
+        (
+            \s+ {STR_ALGO}
+            (
+                (\s+ {CONST_KEYS} \s+ {KEYS})|
+                (\s+ {STRINGS_CONST} \s+ {VALUES})
+            )
+            (\s+ {IDX_CONST})?
+            (\s+ {LEN_CONST})?
+            (\s+ {MINMATCHLEN_CONST} \s+ {LEN})?
+            (\s+ {WITHMATCHLEN_CONST})?
+        )
+    \s*""",
+    "command_lpos": fr"""
+        \s+ {KEY} \s+ {ELEMENT}
+        (
+            (\s+ {RANK_CONST} \s+ {RANK})|
+            (\s+ {COUNT_CONST} \s+ {COUNT})|
+            (\s+ {MAXLEN} \s+ {LEN})
+        )*
+        \s*""",
 }
 
 pipeline = r"(?P<shellcommand>\|.*)?"
@@ -576,7 +622,7 @@ def get_command_grammar(command):
     syntax = GRAMMAR.get(syntax_name)
 
     # If a command is not supported yet, (e.g. command from latest version added
-    # by Redis recently, or command from third Redis module.) return a defualt
+    # by Redis recently, or command from third Redis module.) return a default
     # grammar, so the lexer and completion won't be activated.
     if syntax is None:
         return command_grammar
