@@ -74,8 +74,8 @@ class OutputRender:
         utf-8 decoded.
         """
         decoded = nativestr(value)
-        splitted = "\n".join(decoded.splitlines())  # get rid of last newline
-        return splitted
+        split = "\n".join(decoded.splitlines())  # get rid of last newline
+        return split
 
     @staticmethod
     def render_nested_pair(value):
@@ -163,13 +163,23 @@ class OutputRender:
     def render_simple_string(text):
         """
         If response is b'OK', render simple string always with success color.
-        If Error happend, error will be rendered by ``render_error``
+        If Error happens, error will be rendered by ``render_error``
         """
         if text is None:
             return NIL
         text = ensure_str(text)
         return FormattedText([("class:success", text)])
 
+    @staticmethod
+    def render_help(raw):
+        """
+        render help text message.
+        the command like ``ACL HELP`` and ``MEMORY HELP``
+        will return a list of strings.
+        we render it as plain text
+        """
+        return FormattedText([("class:string", _render_raw_list(raw).decode())])
+
     @staticmethod
     def render_transaction_queue(text):
         """
